@@ -44,7 +44,7 @@ BoxFrame::BoxFrame(QWidget *parent)
     , m_bgManager(nullptr)
     , m_useSolidBackground(false)
 {
-    m_useSolidBackground = getDConfigValue("use-solid-background", false).toBool();
+    m_useSolidBackground = getDConfigValue("useSolidBackground", false).toBool();
     if (m_useSolidBackground)
         return;
 
@@ -53,12 +53,6 @@ BoxFrame::BoxFrame(QWidget *parent)
     connect(m_bgManager, &BackgroundManager::currentWorkspaceBlurBackgroundChanged, this, &BoxFrame::setBlurBackground);
 }
 
-// Message for maintainers: DON'T use QSS to set the background !
-
-// This function takes ~2ms by setting QSS to set backgrounds, but causes show() of
-// ShutdownFrame takes ~260ms to complete. On the other hand, this function takes
-// ~130ms by setting pixmap, yet takes only ~12ms to complete the show() of ShutdownFrame.
-// It'll be more obvious on dual screens environment.
 void BoxFrame::setBackground(const QString &url)
 {
     if (m_lastUrl == url)
@@ -80,23 +74,30 @@ void BoxFrame::setBlurBackground(const QString &url)
 }
 
 /** 缩放图片并缓存
- * @brief BoxFrame::scaledBackground
+ * @brief BoxFrame::scaledBlurBackground
  */
 void BoxFrame::scaledBlurBackground()
 {
     if (m_useSolidBackground)
         return;
-        
+
+    const QSize &size = currentScreen()->size() * currentScreen()->devicePixelRatio();
+    static QString blurBgPath;
+    static QSize lastSize;
+
+    // 当背景图片路径且屏幕大小没有变化，则无需再次加载,减少资源加载耗时
+    if (blurBgPath == m_lastBlurUrl && size == lastSize)
+        return;
+
+    blurBgPath = m_lastBlurUrl;
+    lastSize = size;
+
     QPixmap pixmap(m_lastBlurUrl);
     if (pixmap.isNull())
         pixmap.load(m_defaultBg);
-    if (pixmap.isNull())
-        return;
 
-    const QSize &size = currentScreen()->size() * currentScreen()->devicePixelRatio();
-    QPixmap scaledpixmap = pixmap.scaled(size,
-                               Qt::KeepAspectRatioByExpanding,
-                               Qt::SmoothTransformation);
+    QPixmap scaledpixmap = pixmap.scaled(size, Qt::KeepAspectRatioByExpanding,
+                                         Qt::SmoothTransformation);
     emit backgroundImageChanged(scaledpixmap);
 }
 
@@ -108,16 +109,21 @@ void BoxFrame::scaledBackground()
     if (m_useSolidBackground)
         return;
 
+    // 当背景图片路径且屏幕大小没有变化，则无需再次加载,减少资源加载耗时
+    const QSize &size = currentScreen()->size() * currentScreen()->devicePixelRatio();
+    static QString bgPath;
+
+    if (bgPath == m_lastUrl && m_pixmap.size() == size)
+        return;
+
+    bgPath = m_lastUrl;
+
     QPixmap pixmap(m_lastUrl);
     if (pixmap.isNull())
         pixmap = QPixmap(m_defaultBg);
-    if (pixmap.isNull())
-        return;
 
-    const QSize &size = currentScreen()->size() * currentScreen()->devicePixelRatio();
-    m_pixmap = pixmap.scaled(size,
-                                Qt::KeepAspectRatioByExpanding,
-                                Qt::SmoothTransformation);
+    m_pixmap = pixmap.scaled(size, Qt::KeepAspectRatioByExpanding,
+                             Qt::SmoothTransformation);
     update();
 }
 
@@ -128,7 +134,7 @@ const QScreen *BoxFrame::currentScreen()
 
     int screenIndex = QApplication::desktop()->screenNumber(this);
     QList<QScreen *> screens = qApp->screens();
-    if (screenIndex < screens.count())
+    if (screenIndex < screens.count() && screenIndex != -1)
         return screens[screenIndex];
 
     return qApp->primaryScreen();
@@ -154,3 +160,11 @@ void BoxFrame::moveEvent(QMoveEvent *event)
         m_bgManager->updateBlurBackgrounds();
     QLabel::moveEvent(event);
 }
+
+void BoxFrame::resizeEvent(QResizeEvent *event)
+{
+    scaledBackground();
+    scaledBlurBackground();
+
+    QWidget::resizeEvent(event);
+}
\ No newline at end of file
