@@ -1487,9 +1487,7 @@ void FullScreenFrame::refreshPageView(AppsListModel::AppCategory category)
             pageView->updatePageCount(AppsListModel::AppCategory(i));
             pageView->showCurrentPage(pageView->currentPage());
         }
-    }
 
-    if (m_displayMode == GROUP_BY_CATEGORY && AppsListModel::Search == category) {
         checkCurrentCategoryVisible();
         hideCategoryBoxWidget();
         showCategoryBoxWidget(m_currentCategory);
@@ -1580,7 +1578,6 @@ void FullScreenFrame::updateDockPosition()
     switch (m_appsManager->dockPosition()) {
     case DLauncher::DOCK_POS_TOP:
         m_topSpacing->setFixedHeight(30 + dockGeometry.height());
-        bottomMargin = m_topSpacing->height() + DLauncher::APPS_AREA_TOP_MARGIN;
         m_searchWidget->setLeftSpacing(0);
         m_searchWidget->setRightSpacing(0);
         break;
