@@ -26,16 +26,20 @@
 
 #include <QtGlobal>
 #include <QString>
+#include <QList>
 
 namespace DLauncher {
 
 static const int APP_ITEM_ICON_SIZE = 24;                                            // 小窗口应用图标大小
 static const int APP_CATEGORY_ICON_SIZE = 18;                                        // 小窗口分类项图标大小
-static const int APP_DRAG_ICON_SIZE = 48;
+static const int APP_DRAG_ICON_SIZE = 28;                                            // 小窗口拖拽图标大小
+static const int APP_DLG_ICON_SIZE = 36;                                             // 小窗口卸载弹窗图标大小
 static const int APP_DRAG_SWAP_THRESHOLD = 10;
 static const int APP_DRAG_SCROLL_THRESHOLD = 150;
 static const int APP_DRAG_MININUM_TIME = 300;
 
+static const QList<int> APP_ICON_SIZE_LIST = { 16, 18, 24, 32, 64, 96, 128, 256 };   // 应用图标大小列表
+
 static const int DRAG_THRESHOLD = 15;
 
 static const int CATEGORY_TITLE_WIDGET_HEIGHT = 70;
@@ -95,7 +99,7 @@ static const int DOCK_POS_LEFT = 3;                     // 任务栏位置: 左
 
 static const int CHANGE_PAGE_DELAY_TIME = 250;          // 翻页延时时间，防抖动
 static const QString SOLID_BACKGROUND_COLOR = "#000F27";        // 纯色背景色号
-static const QString DEFAULT_META_CONFIG_NAME = "com.deepin.dde.dde-launcher.dconfig";      // 默认的配置文件名称
+static const QString DEFAULT_META_CONFIG_NAME = "org.deepin.dde.launcher";      // 默认的配置文件名称
 
 static const int MOUSE_LEFTBUTTON = 1;
 static const int MOUSE_RIGHTBUTTON  = 3;
