@@ -68,6 +68,77 @@ ItemInfoList AppsManager::m_userSortedList = QList<ItemInfo>();
 ItemInfoList AppsManager::m_appSearchResultList = QList<ItemInfo>();
 ItemInfoList AppsManager::m_categoryList = QList<ItemInfo>();
 
+bool AppsManager::readJsonFile(QIODevice &device, QSettings::SettingsMap &map)
+{
+    QJsonParseError jsonParser;
+    map = QJsonDocument::fromJson(device.readAll(), &jsonParser).toVariant().toMap();
+
+    return jsonParser.error == QJsonParseError::NoError;
+}
+
+bool AppsManager::writeJsonFile(QIODevice &device, const QSettings::SettingsMap &map)
+{
+    QJsonDocument jsonDocument = QJsonDocument::fromVariant(QVariant::fromValue(map));
+    return device.write(jsonDocument.toJson()) != -1;
+}
+
+void AppsManager::registerSettingsFormat()
+{
+    const QSettings::Format JsonFormat = QSettings::registerFormat("json", readJsonFile, writeJsonFile);
+    m_userSortedSetting = new QSettings(JsonFormat, QSettings::UserScope, "deepin","dde-launcher-app-sorted-list");
+    m_usedSortedSetting = new QSettings(JsonFormat, QSettings::UserScope, "deepin","dde-launcher-app-used-sorted-list");
+    m_categroySortedSetting = new QSettings(JsonFormat, QSettings::UserScope, "deepin","dde-launcher-app-category-used-sorted-list");
+}
+
+QSettings::SettingsMap AppsManager::getCacheMapData(const ItemInfoList &list)
+{
+    auto fillMapData = [ & ](QSettings::SettingsMap &map, const ItemInfo &info) {
+        map.insert("desktop", info.m_desktop);
+        map.insert("appName", info.m_name);
+        map.insert("appKey", info.m_key);
+        map.insert("iconKey", info.m_iconKey);
+        map.insert("categoryId", info.m_categoryId);
+        map.insert("installTime", info.m_installedTime);
+        map.insert("openCount", info.m_openCount);
+        map.insert("firstRunTime", info.m_firstRunTime);
+    };
+
+    QSettings::SettingsMap map;
+    for (int i = 0; i < list.size(); i++) {
+        QSettings::SettingsMap itemMap;
+        const ItemInfo &info = list.at(i);
+        fillMapData(itemMap, info);
+        map.insert(QString("itemInfo_%1").arg(i), itemMap);
+    }
+
+    return map;
+}
+
+const ItemInfoList AppsManager::readCacheData(const QSettings::SettingsMap &map)
+{
+    auto getMapData = [ & ](ItemInfo &info, const QMap<QString, QVariant> &infoMap) {
+        info.m_desktop = infoMap.value("desktop").toString();
+        info.m_name = infoMap.value("appName").toString();
+        info.m_key = infoMap.value("appKey").toString();
+        info.m_iconKey = infoMap.value("iconKey").toString();
+        info.m_categoryId = infoMap.value("categoryId").toLongLong();
+        info.m_installedTime = infoMap.value("installTime").toInt();
+        info.m_openCount = infoMap.value("openCount").toLongLong();
+        info.m_firstRunTime = infoMap.value("firstRunTime").toLongLong();
+    };
+
+    ItemInfoList infoList;
+    for (int i = 0; i < map.size(); i++) {
+        ItemInfo info;
+        const QMap<QString, QVariant> &itemInfoMap = map.value(QString("itemInfo_%1").arg(i)).toMap();
+
+        getMapData(info, itemInfoMap);
+        infoList.append(info);
+    }
+
+    return infoList;
+}
+
 AppsManager::AppsManager(QObject *parent) :
     QObject(parent),
     m_launcherInter(new DBusLauncher(this)),
@@ -93,6 +164,9 @@ AppsManager::AppsManager(QObject *parent) :
         connect(m_filterSetting, &QGSettings::changed, this, &AppsManager::onGSettingChanged);
     }
 
+    // QSettings 添加Json格式支持
+    registerSettingsFormat();
+
     // 分类目录名称
     m_categoryTs.append(tr("Internet"));
     m_categoryTs.append(tr("Chat"));
@@ -316,13 +390,6 @@ void AppsManager::stashItem(const QString &appKey)
  */
 void AppsManager::abandonStashedItem(const QString &appKey)
 {
-    //qDebug() << "bana" << appKey;
-    for (int i(0); i != m_stashList.size(); ++i) {
-        if (m_stashList[i].m_key == appKey) {
-            m_stashList.removeAt(i);
-            break;
-        }
-    }
     //重新获取分类数据，类似wps一个appkey对应多个desktop文件的时候,有可能会导致漏掉
     refreshCategoryInfoList();
 
@@ -388,11 +455,7 @@ void AppsManager::refreshAllList()
 
 void AppsManager::saveUserSortedList()
 {
-    // save cache
-    QByteArray writeBuf;
-    QDataStream out(&writeBuf, QIODevice::WriteOnly);
-    out << m_userSortedList;
-    APP_USER_SORTED_LIST.setValue("list", writeBuf);
+    m_userSortedSetting->setValue("lists", getCacheMapData(m_userSortedList));
 }
 
 /**
@@ -400,11 +463,7 @@ void AppsManager::saveUserSortedList()
  */
 void AppsManager::saveUsedSortedList()
 {
-    QByteArray writeBuf;
-    QDataStream out(&writeBuf, QIODevice::WriteOnly);
-    out << m_usedSortedList;
-
-    APP_USED_SORTED_LIST.setValue("list", writeBuf);
+    m_usedSortedSetting->setValue("lists", getCacheMapData(m_usedSortedList));
 }
 
 void AppsManager::searchApp(const QString &keywords)
@@ -705,6 +764,9 @@ const QPixmap AppsManager::appIcon(const ItemInfo &info, const int size)
     const int iconSize = perfectIconSize(size);
     QPair<QString, int> tmpKey { cacheKey(info) , iconSize };
 
+    // 当开启预加载时，所有资源只能从子线程中加载到缓存，缓存完毕才显示界面．
+    // 否则，就会存在多个线程同时访问QIcon资源的情况，会出现程序崩溃．这个是QIcon明确禁止的．
+
     // 开启子线程加载应用图标时
     if (m_iconCacheThread->isRunning()) {
         IconCacheManager::getPixFromCache(tmpKey, pix);
@@ -776,13 +838,20 @@ void AppsManager::refreshCategoryInfoList()
 
     QStringList filters = SettingValue("com.deepin.dde.launcher", "/com/deepin/dde/launcher/", "filter-keys").toStringList();
 
-    QByteArray readBuf = APP_USED_SORTED_LIST.value("list").toByteArray();
-    QDataStream in(&readBuf, QIODevice::ReadOnly);
-    in >> m_usedSortedList;
-    foreach(auto used , m_usedSortedList) {
-        bool bContains = fuzzyMatching(filters, used.m_key);
-        if (bContains) {
-            m_usedSortedList.removeOne(used);
+    // 如果为空，先从缓存读取一次应用列表数据
+    if (m_usedSortedList.isEmpty()) {
+        if (APP_USED_SORTED_LIST.contains("list")) {
+            QByteArray readBuf = APP_USED_SORTED_LIST.value("list").toByteArray();
+            QDataStream in(&readBuf, QIODevice::ReadOnly);
+            in >> m_usedSortedList;
+            foreach(auto &used , m_usedSortedList) {
+                bool bContains = fuzzyMatching(filters, used.m_key);
+                if (bContains)
+                    m_usedSortedList.removeOne(used);
+            }
+        } else {
+            // 读取json缓存文件
+            m_usedSortedList.append(readCacheData(m_usedSortedSetting->value("lists").toMap()));
         }
     }
 
@@ -794,9 +863,15 @@ void AppsManager::refreshCategoryInfoList()
     for (; beginCategoryIndex < endCategoryIndex; beginCategoryIndex++) {
         ItemInfoList itemInfoList;
 
-        QByteArray readCategoryBuf = APP_CATEGORY_USED_SORTED_LIST.value(QString("%1").arg(beginCategoryIndex)).toByteArray();
-        QDataStream categoryIn(&readCategoryBuf, QIODevice::ReadOnly);
-        categoryIn >> itemInfoList;
+        if (APP_CATEGORY_USED_SORTED_LIST.contains(QString("%1").arg(beginCategoryIndex))) {
+            QByteArray readCategoryBuf = APP_CATEGORY_USED_SORTED_LIST.value(QString("%1").arg(beginCategoryIndex)).toByteArray();
+            QDataStream categoryIn(&readCategoryBuf, QIODevice::ReadOnly);
+            categoryIn >> itemInfoList;
+        } else {
+            // 从json读取缓存数据
+            itemInfoList  << readCacheData(m_categroySortedSetting->value(QString("AppCategory_%1").arg(beginCategoryIndex)).toMap());
+        }
+
 
         m_appInfoLock.lockForWrite();
         // 当缓存数据与应用商店数据有差异时，以应用商店数据为准
@@ -833,49 +908,45 @@ void AppsManager::refreshCategoryInfoList()
  */
 void AppsManager::refreshUsedInfoList()
 {
-    if (m_usedSortedList.isEmpty()) {
-        QByteArray readBuffer = APP_USED_SORTED_LIST.value("list").toByteArray();
+    if (!m_usedSortedList.isEmpty()) {
+        saveUsedSortedList();
+        return;
+    }
+
+    if (APP_USED_SORTED_LIST.contains("list")) {
+        QByteArray readBuffer;
         QDataStream in(&readBuffer, QIODevice::ReadOnly);
         in >> m_usedSortedList;
-
-        if (m_usedSortedList.isEmpty()) {
-            m_usedSortedList = m_allAppInfoList;
-        }
-
-        for (QList<ItemInfo>::ConstIterator it = m_allAppInfoList.constBegin(); it != m_allAppInfoList.constEnd(); ++it) {
-            if (!m_usedSortedList.contains(*it)) {
-                m_usedSortedList.append(*it);
-            }
-        }
-
-        for (QList<ItemInfo>::iterator it = m_usedSortedList.begin(); it != m_usedSortedList.end();) {
-            if (m_allAppInfoList.contains(*it)) {
-                ++it;
-            } else {
-                it = m_usedSortedList.erase(it);
-            }
-        }
-
-        updateUsedListInfo();
+    } else {
+        m_usedSortedList.append(readCacheData(m_usedSortedSetting->value("lists").toMap()));
     }
-    // 保存到qSetting配置文件
+
+    if (m_usedSortedList.isEmpty())
+        m_usedSortedList = m_allAppInfoList;
+
+    for (QList<ItemInfo>::ConstIterator it = m_allAppInfoList.constBegin(); it != m_allAppInfoList.constEnd(); ++it) {
+        if (!m_usedSortedList.contains(*it))
+            m_usedSortedList.append(*it);
+    }
+
+    for (QList<ItemInfo>::iterator it = m_usedSortedList.begin(); it != m_usedSortedList.end();) {
+        if (m_allAppInfoList.contains(*it)) {
+            ++it;
+        } else {
+            it = m_usedSortedList.erase(it);
+        }
+    }
+
+    updateUsedListInfo();
     saveUsedSortedList();
 }
 
-/**
- * @brief AppsManager::refreshCategoryUsedInfoList 保存全屏分类排序数据
- */
 void AppsManager::refreshCategoryUsedInfoList()
 {
-    // 保存排序信息
-    QHash<AppsListModel::AppCategory, ItemInfoList>::iterator categoryAppsIter = m_appInfos.begin();
-    for (; categoryAppsIter != m_appInfos.end(); ++categoryAppsIter) {
-        int category = categoryAppsIter.key();
-
-        QByteArray writeBuf;
-        QDataStream out(&writeBuf, QIODevice::WriteOnly);
-        out << categoryAppsIter.value();
-        APP_CATEGORY_USED_SORTED_LIST.setValue(QString("%1").arg(category), writeBuf);
+    QHash<AppsListModel::AppCategory, ItemInfoList>::iterator categoryApps = m_appInfos.begin();
+    for (; categoryApps != m_appInfos.end(); ++categoryApps) {
+        int category = categoryApps.key();
+        m_categroySortedSetting->setValue(QString("AppCategory_%1").arg(category), getCacheMapData(categoryApps.value()));
     }
 }
 
@@ -886,9 +957,14 @@ void AppsManager::refreshUserInfoList()
 {
     if (m_userSortedList.isEmpty()) {
         // first reads the config file.
-        QByteArray readBuffer = APP_USER_SORTED_LIST.value("list").toByteArray();
-        QDataStream in(&readBuffer, QIODevice::ReadOnly);
-        in >> m_userSortedList;
+        if (APP_USER_SORTED_LIST.contains("list")) {
+            QByteArray readBuffer = APP_USER_SORTED_LIST.value("list").toByteArray();
+            QDataStream in(&readBuffer, QIODevice::ReadOnly);
+            in >> m_userSortedList;
+        } else {
+            // 读取缓存
+            m_userSortedList.append(readCacheData(m_userSortedSetting->value("lists").toMap()));
+        }
 
         // if data cache file is empty.
         if (m_userSortedList.isEmpty()) {
@@ -1067,18 +1143,10 @@ void AppsManager::generateCategoryMap()
     m_appInfoLock.unlock();
 
     // remove uninstalled app item
-    for (auto it(m_usedSortedList.begin()); it != m_usedSortedList.end();) {
-        int idx = m_allAppInfoList.indexOf(*it);
-
-        // 如果是分类模式，那么再查一下 m_stashList，为了不要更新 m_usedSortedList
-        if (idx == -1 && (m_calUtil->displayMode() == GROUP_BY_CATEGORY)) {
-            idx = m_stashList.indexOf(*it);
+    foreach (auto it, m_usedSortedList) {
+        if (!m_allAppInfoList.contains(it) || m_stashList.contains(it)) {
+            m_usedSortedList.removeOne(it);
         }
-
-        if (idx == -1)
-            it = m_usedSortedList.erase(it);
-        else
-            ++it;
     }
 
     // 从所有应用中获取所有分类目录类型id,存放到临时列表categoryID中
@@ -1148,6 +1216,10 @@ void AppsManager::refreshAppAutoStartCache(const QString &type, const QString &d
  */
 void AppsManager::onSearchTimeOut()
 {
+    if (m_searchText.isEmpty()) {
+        return;
+    }
+
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(m_launcherInter->Search(m_searchText), this);
     connect(watcher, &QDBusPendingCallWatcher::finished, this, [ = ](QDBusPendingCallWatcher * w) {
         if (w->isError()) qDebug() << w->error();
@@ -1231,6 +1303,8 @@ void AppsManager::handleItemChanged(const QString &operation, const ItemInfo &ap
         //一般情况是不需要的，但是类似wps这样的程序有点特殊，删除一个其它的二进制程序也删除了，需要保存列表，否则刷新的时候会刷新出齿轮的图标
         //新增和更新则无必要
         saveUsedSortedList();
+        // 如果应用被成功删除，则从临时列表中删除应用
+        m_stashList.removeAll(appInfo);
     } else if (operation == "updated") {
 
         Q_ASSERT(m_allAppInfoList.contains(appInfo));
