@@ -24,16 +24,20 @@
 #include <QLabel>
 #include <QTimer>
 
+#include <DGuiApplicationHelper>
+
+DGUI_USE_NAMESPACE
+
 class QDBusInterface;
 class DatetimeWidget : public QWidget
 {
     Q_OBJECT
 
 public:
-    DatetimeWidget(QWidget *parent = nullptr);
-    ~DatetimeWidget() override;
+    explicit DatetimeWidget(QWidget *parent = nullptr);
 
     int getDateTextWidth();
+    void updateTime();
 
 signals:
     void clicked();
@@ -41,14 +45,14 @@ signals:
 protected:
     void mouseReleaseEvent(QMouseEvent *) Q_DECL_OVERRIDE;
 
-private:
-    void updateTime();
+private slots:
+    void onThemeTypeChange(DGuiApplicationHelper::ColorType themeType);
 
 private:
     QLabel *m_currentTimeLabel;
     QLabel *m_currentDateLabel;
     QTimer *m_refreshDateTimer;
-    QDBusInterface* m_24HourFormatInter;
+    QDBusInterface *m_24HourFormatInter;
 };
 
 #endif
