@@ -23,12 +23,13 @@
 
 #include <QPainter>
 
-MaskQWidget::MaskQWidget(QWidget *parent) : QWidget(parent)
+MaskQWidget::MaskQWidget(QWidget *parent)
+    : QWidget(parent)
+    , m_color(Qt::transparent)
 {
-    m_color = new QColor(0,0,0,0);
 }
 
-void MaskQWidget::setColor(QColor *color)
+void MaskQWidget::setColor(QColor color)
 {
     m_color = color;
 }
@@ -37,7 +38,7 @@ void MaskQWidget::paintEvent(QPaintEvent *event)
 {
     QPainter painter(this);
     painter.setRenderHint(QPainter::Antialiasing);  // 反锯齿;
-    painter.setBrush(QBrush(*m_color));
+    painter.setBrush(QBrush(m_color));
     painter.setPen(Qt::transparent);
     QRect rect = this->rect();
     rect.setWidth(rect.width());
