@@ -24,13 +24,16 @@
 #include <QWidget>
 #include <QLabel>
 
+#include <DGuiApplicationHelper>
+
+DGUI_USE_NAMESPACE
+
 class MiniFrameSwitchBtn : public QWidget
 {
     Q_OBJECT
 
 public:
-    MiniFrameSwitchBtn(QWidget *parent = nullptr);
-    ~MiniFrameSwitchBtn() override;
+    explicit MiniFrameSwitchBtn(QWidget *parent = nullptr);
 
     void updateStatus(int status);
     void click();
@@ -43,6 +46,8 @@ protected:
     void enterEvent(QEvent *event) override;
     void leaveEvent(QEvent *event) override;
     void mouseReleaseEvent(QMouseEvent *event) override;
+
+public slots:
     void updateIcon();
 
 private:
@@ -51,7 +56,6 @@ private:
     QLabel *m_allIconLabel;
     bool m_hover = false;
     QColor m_color;
-
 };
 
 #endif
