@@ -23,22 +23,24 @@
 #define MODETOGGLEBUTTON_H
 
 #include <DToolButton>
+#include <DGuiApplicationHelper>
 
 DWIDGET_USE_NAMESPACE
+DGUI_USE_NAMESPACE
 
 class ModeToggleButton : public DToolButton
 {
     Q_OBJECT
 
 public:
-    ModeToggleButton(QWidget *parent = nullptr);
+    explicit ModeToggleButton(QWidget *parent = nullptr);
 
 protected:
     void paintEvent(QPaintEvent *event) override;
     void enterEvent(QEvent *event) override;
     void leaveEvent(QEvent *event) override;
 
-private:
+private slots:
     void resetStyle();
 
 private:
